==> aws-java-sdk-api-gateway-1.11.28-sources.jar: com/amazonaws/services/apigateway/model/GetUsagePlansResult.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.apigateway.model;

import java.io.Serializable;

/**
 * <p>
 * Represents a collection of usage plans for an AWS account.
 * </p>
 * <div class="seeAlso"> <a href=
 * "http://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-api-usage-plans.html"
 * >Create and Use Usage Plans</a> </div>
 */
public class GetUsagePlansResult implements Serializable, Cloneable {

    private String position;
    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     */
    private java.util.List<UsagePlan> items;

    /**
     * @param position
     */

    public void setPosition(String position) {
        this.position = position;
    }

    /**
     * @return
     */

    public String getPosition() {
        return this.position;
    }

    /**
     * @param position
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public GetUsagePlansResult withPosition(String position) {
        setPosition(position);
        return this;
    }

    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     * 
     * @return Gets the current item when enumerating the collection of
     *         <a>UsagePlan</a>.
     */

    public java.util.List<UsagePlan> getItems() {
        return items;
    }

    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     * 
     * @param items
     *        Gets the current item when enumerating the collection of
     *        <a>UsagePlan</a>.
     */

    public void setItems(java.util.Collection<UsagePlan> items) {
        if (items == null) {
            this.items = null;
            return;
        }

        this.items = new java.util.ArrayList<UsagePlan>(items);
    }

    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     * <p>
     * <b>NOTE:</b> This method appends the values to the existing list (if
     * any). Use {@link #setItems(java.util.Collection)} or
     * {@link #withItems(java.util.Collection)} if you want to override the
     * existing values.
     * </p>
     * 
     * @param items
     *        Gets the current item when enumerating the collection of
     *        <a>UsagePlan</a>.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public GetUsagePlansResult withItems(UsagePlan... items) {
        if (this.items == null) {
            setItems(new java.util.ArrayList<UsagePlan>(items.length));
        }
        for (UsagePlan ele : items) {
            this.items.add(ele);
        }
        return this;
    }

    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     * 
     * @param items
     *        Gets the current item when enumerating the collection of
     *        <a>UsagePlan</a>.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public GetUsagePlansResult withItems(java.util.Collection<UsagePlan> items) {
        setItems(items);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getPosition() != null)
            sb.append("Position: " + getPosition() + ",");
        if (getItems() != null)
            sb.append("Items: " + getItems());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof GetUsagePlansResult == false)
            return false;
        GetUsagePlansResult other = (GetUsagePlansResult) obj;
        if (other.getPosition() == null ^ this.getPosition() == null)
            return false;
        if (other.getPosition() != null
                && other.getPosition().equals(this.getPosition()) == false)
            return false;
        if (other.getItems() == null ^ this.getItems() == null)
            return false;
        if (other.getItems() != null
                && other.getItems().equals(this.getItems()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getPosition() == null) ? 0 : getPosition().hashCode());
        hashCode = prime * hashCode
                + ((getItems() == null) ? 0 : getItems().hashCode());
        return hashCode;
    }

    @Override
    public GetUsagePlansResult clone() {
        try {
            return (GetUsagePlansResult) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}

==> aws-java-sdk-api-gateway-1.11.33-sources.jar: com/amazonaws/services/apigateway/model/GetUsagePlansResult.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.apigateway.model;

import java.io.Serializable;

/**
 * <p>
 * Represents a collection of usage plans for an AWS account.
 * </p>
 * <div class="seeAlso"> <a href=
 * "http://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-api-usage-plans.html"
 * >Create and Use Usage Plans</a> </div>
 */
public class GetUsagePlansResult extends
        com.amazonaws.AmazonWebServiceResult<com.amazonaws.ResponseMetadata>
        implements Serializable, Cloneable {

    private String position;
    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     */
    private java.util.List<UsagePlan> items;

    /**
     * @param position
     */

    public void setPosition(String position) {
        this.position = position;
    }

    /**
     * @return
     */

    public String getPosition() {
        return this.position;
    }

    /**
     * @param position
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public GetUsagePlansResult withPosition(String position) {
        setPosition(position);
        return this;
    }

    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     * 
     * @return Gets the current item when enumerating the collection of
     *         <a>UsagePlan</a>.
     */

    public java.util.List<UsagePlan> getItems() {
        return items;
    }

    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     * 
     * @param items
     *        Gets the current item when enumerating the collection of
     *        <a>UsagePlan</a>.
     */

    public void setItems(java.util.Collection<UsagePlan> items) {
        if (items == null) {
            this.items = null;
            return;
        }

        this.items = new java.util.ArrayList<UsagePlan>(items);
    }

    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     * <p>
     * <b>NOTE:</b> This method appends the values to the existing list (if
     * any). Use {@link #setItems(java.util.Collection)} or
     * {@link #withItems(java.util.Collection)} if you want to override the
     * existing values.
     * </p>
     * 
     * @param items
     *        Gets the current item when enumerating the collection of
     *        <a>UsagePlan</a>.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public GetUsagePlansResult withItems(UsagePlan... items) {
        if (this.items == null) {
            setItems(new java.util.ArrayList<UsagePlan>(items.length));
        }
        for (UsagePlan ele : items) {
            this.items.add(ele);
        }
        return this;
    }

    /**
     * <p>
     * Gets the current item when enumerating the collection of
     * <a>UsagePlan</a>.
     * </p>
     * 
     * @param items
     *        Gets the current item when enumerating the collection of
     *        <a>UsagePlan</a>.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public GetUsagePlansResult withItems(java.util.Collection<UsagePlan> items) {
        setItems(items);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getPosition() != null)
            sb.append("Position: " + getPosition() + ",");
        if (getItems() != null)
            sb.append("Items: " + getItems());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof GetUsagePlansResult == false)
            return false;
        GetUsagePlansResult other = (GetUsagePlansResult) obj;
        if (other.getPosition() == null ^ this.getPosition() == null)
            return false;
        if (other.getPosition() != null
                && other.getPosition().equals(this.getPosition()) == false)
            return false;
        if (other.getItems() == null ^ this.getItems() == null)
            return false;
        if (other.getItems() != null
                && other.getItems().equals(this.getItems()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getPosition() == null) ? 0 : getPosition().hashCode());
        hashCode = prime * hashCode
                + ((getItems() == null) ? 0 : getItems().hashCode());
        return hashCode;
    }

    @Override
    public GetUsagePlansResult clone() {
        try {
            return (GetUsagePlansResult) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}
